@@ -7,11 +7,8 @@ from redturtle.voltoplugin.editablefooter import _
 
 
 class EditableFooterForm(controlpanel.RegistryEditForm):
-
     schema = IEditableFooterSettings
-    label = _(
-        "editable_footer_settings_label", default="Editable Footer Settings"
-    )
+    label = _("editable_footer_settings_label", default="Editable Footer Settings")
     description = _(
         "editable_footer_settings_help",
         default="Set infos for columns in footer.",
